=======
Drivers
=======

Cloud management
----------------

.. cloud_driver_doc:: universal

.. cloud_driver_doc:: devstack

.. cloud_driver_doc:: saltcloud


Power management
----------------

.. driver_doc:: libvirt

.. driver_doc:: ipmi


Node discover
-------------

.. driver_doc:: node_list


Service drivers
---------------

.. driver_doc:: process

.. driver_doc:: system_service

.. driver_doc:: salt_service


Container drivers
-----------------

.. driver_doc:: docker_container
